#
# spec file for package nelm
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           nelm
Version:        1.7.0
Release:        1.1
Summary:        Helm 3 alternative
License:        Apache-2.0
URL:            https://github.com/werf/nelm
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  bash-completion
BuildRequires:  fish
BuildRequires:  go >= 1.23
BuildRequires:  zsh

%description
Nelm is a Helm 3 alternative. It is a Kubernetes deployment tool that manages
Helm Charts and deploys them to Kubernetes and also is the deployment engine of
werf. It can do (almost) everything that Helm does, but better, and even quite
some on top of it. Nelm is based on improved and partially rewritten Helm 3
codebase, to introduce:

* terraform plan-like capabilities;
* replacement of 3-Way Merge with Server-Side Apply;
* secrets management;
* advanced resource ordering capabilities;
* improved resource state/error tracking;
* continuous printing of logs, events, resource statuses and errors during
  deploy;
* lots of fixes for Helm 3 bugs, e.g. "no matches for kind Deployment in
  version apps/v1beta1";
* ... and more.

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       fish
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description -n %{name}-fish-completion
Fish command line completion support for %{name}.

%package -n %{name}-zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       zsh
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description -n %{name}-zsh-completion
zsh command line completion support for %{name}.

%prep
%autosetup -p 1 -a 1

%build
go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags=" \
   -X github.com/werf/nelm/internal/common.Brand=Nelm \
   -X github.com/werf/nelm/internal/common.Version=%{version}" \
   -o bin/%{name} ./cmd/%{name}

%install
# Install the binary.
install -D -m 0755 bin/%{name} %{buildroot}/%{_bindir}/%{name}

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/%{name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{name}

# create the fish completion file
mkdir -p %{buildroot}%{_datarootdir}/fish/vendor_completions.d/
%{buildroot}/%{_bindir}/%{name} completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh/site-functions/
%{buildroot}/%{_bindir}/%{name} completion zsh > %{buildroot}%{_datarootdir}/zsh/site-functions/_%{name}

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}

%files -n %{name}-bash-completion
%{_datarootdir}/bash-completion/completions/%{name}

%files -n %{name}-fish-completion
%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

%files -n %{name}-zsh-completion
%{_datarootdir}/zsh/site-functions/_%{name}

%changelog
* Wed Jun 18 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 1.7.0:
  * feat: `--force-adoption` to disable release annotations checks
  * feat: expose release labels in `release get`
* Mon Jun  9 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 1.6.0:
  * Features
  - feat: include_debug/tpl_debug/printf_debug/dump_debug and
    detailed template errors
* Wed Jun  4 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 1.5.0:
  * Features
  - NELM_FEAT_PREVIEW_V2 feature gate (f7ad0ab)
  - native release list command (ff9e1f0)
  - native release uninstall command (4d85484)
  * Bug Fixes
  - show stack traces with NELM_FEAT_PERIODIC_STACK_TRACES=true
    (20310db)
* Fri May 23 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 1.4.1:
  * Bug Fixes
  - improve values handling; add more trace logs (358855f)
* Wed May 14 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 1.4.0:
  * Features
  - --no-install-crds for release install/plan (efc22bc)
  - --print-values option for release get (f41f615)
  - --release-labels option for release install (9b20bc0)
  - --timeout option for release install/rollback/uninstall/plan
    (d563296)
  * Bug Fixes
  - disallow unknown NELM_FEAT_.* env vars (7e25a16)
  * Dependencies
  - chore: update 3p-helm module
* Wed May  7 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 1.3.0:
  * Features
  - allow specifying remote charts in cli commands (b21329c)
* Wed Apr 30 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 1.2.2:
  * chore: release 1.2.2
  * fix: improve log color detection
* Fri Apr 25 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 1.2.1:
  * chore: bump alpha
  * chore: release 1.2.1
  * fix: `release plan` shows insignificant changes for no reason
  * chore: bump channels
* Thu Apr 24 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 1.2.0:
  * Features
  - enable colors by default in some popular CI systems (d3aa7b8)
  * Bug Fixes
  - Buildah reexec sets wrong HOME dir (4eb656e)
  - default kubeconfig not used on empty string kubeconfigpath
    action option (ffc2132)
  * Changelog
  - chore: release 1.2.0
  - feat: enable colors by default in some popular CI systems
  - refactor: move log color setup outside of actions
  - refactor: get rid of EnvSettings and Configuration structs of
    Helm
  - chore: update 3p-helm and common-go modules
  - fix: Buildah reexec sets wrong HOME dir
  - fix: default kubeconfig not used on empty string
    kubeconfigpath action option
  - docs: Add production readiness note
* Wed Apr 16 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 1.1.5:
  * chore: bump alpha
  * chore: release 1.1.5
  * fix: chart dir path and revision options/arguments to some
    commands ignored
  * chore: bump alpha
* Sun Apr 13 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 1.1.4:
  * Bug Fixes
  - allow werf.io/sensitive: false for Secrets (53665fd)
  - possible panic in tracking flux canary resource (c6861bf)
* Fri Apr 11 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 1.1.3:
  * Bug Fixes
  - nelm version shows 0.0.0 (5d79185)
  * Dependencies
  - chore: bump alpha
  - chore: release 1.1.3
  - chore: bump alpha
* Fri Apr 11 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 1.1.2:
  * fix: error if `$KUBECONFIG` has multiple files; major rework of
    K8s client setup
  * refactor: ability to trace structs with spew lib
  * refactor: use actions options as command configs
  * refactor: move logging setup out of Actions
  * chore(release): update tuf repo address
  * Add Future plans to README
  * Tiny corrections for README
  * chore: update builder image
  * chore: reformat code
  * refactor: change package structure and names
  * refactor: extract internal packages to `/internal`
  * refactor: prepare to extract internal packages
  * Add Known issues to README
  * chore: bump channels
* Tue Apr  1 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 1.1.1:
  * chore: release 1.1.1
  * fix: wrong `nelm version` output
  * docs: update README.md
  * docs: update README.md
  * docs: fix grammar in README.md
  * fix: make `info` log level less verbose
  * docs: update README.md and release docs
  * docs: update readme
  * docs: update readme
  * chroe: add toc markdown generator task
  * docs: rewrite README.md
  * chore: update github release message
  * chore: bump channels
* Fri Mar 28 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package nelm: Helm 3 alternative. It is a Kubernetes
  deployment tool that manages Helm Charts and deploys them to
  Kubernetes
